@@ -5,10 +5,30 @@
 #' This script calculates the minor allele frequency for each locus and updates
 #' the locus metadata for FreqHomRef, FreqHomSnp, FreqHets and MAF (if it
 #' exists). It then uses the updated metadata for MAF to filter loci.
+#' 
+#' @details 
+#' Careful consideration needs to be given to the settings to be used for this 
+#' fucntion. When the filter is applied globally (i.e. \code{by.pop=FALSE}) but 
+#' the data include multiple population, there is the risk to remove markers 
+#' because the allele frequencies is low (at global level) but the allele frequencies
+#' for the same markers may be high within some of the populations (especially if 
+#' the per-population sample size is small). Similarly, not always it is a 
+#' sensible choice to run this function using \code{by.pop=TRUE} because allele 
+#' that are rare in a population may be very common in other, but the (possible) 
+#' allele frequencies will depend on the sample size within each population. 
+#' Where the purpose of filtering for MAF is to remove possible spurious alleles 
+#' (i.e. sequencing errors), it is perhaps better to filter based on the number 
+#' of times an allele is observed (MAC, Minimum Allele Count), under the 
+#' assumption that if an allele is observed >MAC, it is fairly rare to be an error.
+#' \bold{From v2.1} The threshold can take values > 1. In this case, these are 
+#' interpreted as a threshold for MAC.
+#' 
 #'
 #' @param x Name of the genlight object containing the SNP data [required].
 #' @param threshold Threshold MAF -- loci with a MAF less than the threshold
-#' will be removed [default 0.01].
+#' will be removed [default 0.01]. If a value > 1 is provided it will be 
+#' interpreted as MAC (i.e. the minimum number of times an allele needs to be 
+#' observed).
 #' @param by.pop Whether MAF should be calculated by population [default FALSE].
 #' @param pop.limit Minimum number of populations in which MAF should be less 
 #' than the threshold for a locus to be filtered out. Only used if by.pop=TRUE. 
@@ -98,7 +118,7 @@ gl.filter.maf <- function(x,
     }
     
     # FUNCTION SPECIFIC ERROR CHECKING
-    
+    if(threshold >= 1) threshold <- threshold/(length(indNames(x))*mean(ploidy(x)))
     if (threshold > 0.5 | threshold <= 0) {
         cat(
             warn(
@@ -116,7 +136,7 @@ gl.filter.maf <- function(x,
                 "  Removing loci with MAF <",threshold, "in at least",pop.limit,"populations and recalculating FreqHoms and FreqHets\n"
             ))
         }
-        x <- utils.recalc.maf(x, verbose = 0)
+        #x <- utils.recalc.maf(x, verbose = 0)
         pop.list <- seppop(x)
         
         # getting populations with more than ind.limit
@@ -264,7 +284,9 @@ gl.filter.maf <- function(x,
             
             p_all_pre <-
                 ggplot(as.data.frame(maf_pre), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Pre-filter SNP MAF\nOver all populations") + 
                 ylab("Count") + 
@@ -273,7 +295,9 @@ gl.filter.maf <- function(x,
             
             p_all_post <-
                 ggplot(as.data.frame(maf_post), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Post-filter SNP MAF\nOver all populations") + 
                 ylab("Count") + 
@@ -294,7 +318,9 @@ gl.filter.maf <- function(x,
             }
             p_all_pre <-
                 ggplot(as.data.frame(maf_pre), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Pre-filter SNP MAF\nOver all populations") + 
                 ylab("Count") + 
@@ -303,7 +329,9 @@ gl.filter.maf <- function(x,
             
             p_all_post <-
                 ggplot(as.data.frame(maf_post), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Post-filter SNP MAF\nOver all populations") + 
                 ylab("Count") + 
@@ -324,7 +352,9 @@ gl.filter.maf <- function(x,
             
             p_all_pre <-
                 ggplot(as.data.frame(maf_pre), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Pre-filter SNP MAF") + 
                 ylab("Count") + 
@@ -333,7 +363,9 @@ gl.filter.maf <- function(x,
             
             p_all_post <-
                 ggplot(as.data.frame(maf_post), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Post-filter SNP MAF") + 
                 ylab("Count") + 
@@ -353,7 +385,9 @@ gl.filter.maf <- function(x,
             
             p_all_pre <-
                 ggplot(as.data.frame(maf_pre), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Pre-filter SNP MAF") + 
                 ylab("Count") + 
@@ -362,7 +396,9 @@ gl.filter.maf <- function(x,
             
             p_all_post <-
                 ggplot(as.data.frame(maf_post), aes(x = maf)) + 
-                geom_histogram(bins = bins,color = plot_colors_all[1],fill = plot_colors_all[2]) +
+                geom_histogram(bins = bins,
+                               color = plot_colors_all[1],
+                               fill = plot_colors_all[2]) +
                 geom_vline(xintercept = threshold,color = "red",size = 1) + 
                 xlab("Post-filter SNP MAF") + 
                 ylab("Count") + 
@@ -387,6 +423,7 @@ gl.filter.maf <- function(x,
         x2@other$loc.metrics.flags$FreqHomRef <- FALSE
         x2@other$loc.metrics.flags$FreqHomSnp <- FALSE
         x2@other$loc.metrics.flags$CallRate <- FALSE
+        x2@other$loc.metrics.flags$allna <- FALSE
     }
     
     # REPORT A SUMMARY
